@@ -203,11 +203,13 @@ def main(argv):
                 print("\n--proxy             Sets Http proxy")
                 print("--proxysec          Sets Https proxy")
                 return sys.exit(0)
-            elif arg == "deltav":
+            elif arg == "deltav" or arg == "version":
                 print('')
                 print('python -m artify -c deltav -t <version_change> -a <architecture_type>')
+                print('python -m artify -c version -t <version_change> -a <architecture_type>')
                 print("Or")
                 print("python -m artify --command deltav --type <version_change> --archtype <architecture_type>")
+                print("python -m artify --command version --type <version_change> --archtype <architecture_type>")
                 print("Mandatory argument(s): ")
                 print("-t, --type          Type of version change: major, minor, patch, auto")
                 print("e.g --type major    1.0.0-alpha => 2.0.0-alpha")
@@ -257,8 +259,10 @@ def main(argv):
                 print('python -m artify --help deploy       Help on how to deploy to AWX host')
                 print('python -m artify --help syncrepo     Help on how to commit and push code to repository')
                 print('python -m artify --help deltav       Help on how to change version number')
+                print('python -m artify --help version       Help on how to change version number')
                 print("python -m artify --help create       Help on how to generate template files")
                 print("python -m artify --help extract      Help on how to use the extract command") 
+                print("python -m artify --help archive      Help on how to use archive command")
                 return sys.exit(0)
         elif opt == "--debug":
             debug = 1
@@ -278,7 +282,7 @@ def main(argv):
             proxies['https'] = arg    
             
         elif opt == '--file2':
-            if action == 'deltav':
+            if action == 'deltav' or action == 'version':
                 version_file2 = arg 
             if action == 'nexus':
                 artifact_name2 = arg
@@ -311,7 +315,7 @@ def main(argv):
                 if archive_format == '':
                     print('Please specify archive format e.g zip, tar, gztar, bztar, xztar')
                     return sys.exit(2)
-            elif action == 'deltav':
+            elif action == 'deltav' or action == 'version':
                 version_file1 = arg
             else:
                 print("Invalid command specified: param: -f")
@@ -464,7 +468,7 @@ def main(argv):
             print("Invalid nexus format entered")
             return sys.exit(2)
             
-    elif action == 'deltav':
+    elif action == 'deltav' or action == 'version':
         change_version.modify_version()
     elif action == 'syncrepo':
         syncrepo.commit_push_changes(commit_message)
